Documentation
¶
Overview ¶
package page provides mechanisms and data for generating a WriteFreely page.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type StaticPage ¶
type StaticPage struct {
// App configuration
config.AppCfg
Version string
CustomCSS bool
// Request values
Path string
Username string
Values map[string]string
Flashes []string
CanViewReader bool
IsAdmin bool
CanInvite bool
}
func (StaticPage) OfficialVersion ¶ added in v0.13.0
func (sp StaticPage) OfficialVersion() string
func (*StaticPage) SanitizeHost ¶
func (sp *StaticPage) SanitizeHost(cfg *config.Config)
SanitizeHost alters the StaticPage to contain a real hostname. This is especially important for the Tor hidden service, as it can be served over proxies, messing up the apparent hostname.
Click to show internal directories.
Click to hide internal directories.