parse

package
v0.16.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 29, 2025 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Overview

Package parse assists in the parsing of plain text posts

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func PostLede

func PostLede(t string, includePunc bool) string

PostLede attempts to extract the first thought of the given post, generally contained within the first line or sentence of text.

func TruncToWord

func TruncToWord(s string, l int) (string, bool)

TruncToWord truncates the given text to the provided limit.

func Truncate added in v0.15.0

func Truncate(s string, l int) string

Truncate truncates the given text to the provided limit, returning the original string if it's shorter than the limit.

Types

This section is empty.

Jump to