spam

package
v0.16.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 29, 2025 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CleanEmail

func CleanEmail(email string) string

CleanEmail takes an email address and strips it down to a unique address that can be blocked.

func GetIP

func GetIP(r *http.Request) string

func HoneypotFieldName

func HoneypotFieldName() string

Types

This section is empty.

Jump to