Documentation
¶
Overview ¶
Package parse assists in the parsing of plain text posts
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PostLede ¶
PostLede attempts to extract the first thought of the given post, generally contained within the first line or sentence of text.
func TruncToWord ¶
TruncToWord truncates the given text to the provided limit.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.