Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CleanEmail ¶
CleanEmail takes an email address and strips it down to a unique address that can be blocked.
func HoneypotFieldName ¶
func HoneypotFieldName() string
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.